Magma.PromptResult (Magma v0.3.2)

Copy Markdown View Source

Stores the result of an LLM prompt execution.

Each prompt result is linked to its originating Magma.Prompt and records the Magma.Generation parameters used for execution.

Stored in the prompts/__prompt_results__/ directory with timestamped filenames.

Summary

Functions

Loads a document from the given path or document.

Loads a document from the given path or document and raises an exception in error cases.

Loads a document from the given Obsidian link, i.e. a string of the form "[[name]]".

Types

t()

@type t() :: %Magma.PromptResult{
  aliases: term(),
  content: term(),
  created_at: term(),
  custom_metadata: term(),
  generation: term(),
  name: term(),
  path: term(),
  prompt: term(),
  tags: term()
}

Functions

build_name(result)

controls(prompt_result)

create(prompt, attrs \\ [], opts \\ [])

dir()

load(document)

Loads a document from the given path or document.

If the loaded document is not of the proper document type an Magma.InvalidDocumentType exception is returned in an :error tuple.

load!(document_or_path)

Loads a document from the given path or document and raises an exception in error cases.

load_linked(link)

Loads a document from the given Obsidian link, i.e. a string of the form "[[name]]".

If the referenced document is not of the proper document type an Magma.InvalidDocumentType exception is returned in an :error tuple.

new(prompt, attrs \\ [])

new!(prompt, attrs \\ [])