Magma.Generation adapter for manual prompt execution.
Copies the assembled prompt to the clipboard and optionally waits for the user to paste back the result.
Magma.Generation adapter for manual prompt execution.
Copies the assembled prompt to the clipboard and optionally waits for the user to paste back the result.